@@ -1,12 +1,12 @@
 import argparse
 import sys
 
-from cra import create_react_app
+from .cra import create_react_app
 
 
 def parse_args():
     parser = argparse.ArgumentParser(
-        description='Create React App with TypeScript and tailwindcss',
+        description='Create React App with TypeScript and Tailwind CSS',
         prog='cra',
         allow_abbrev=False,
     )
